"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @file webpackDevServer
 * @author WenCe
 */
require("./babelRegister");
var webpack_1 = __importDefault(require("webpack"));
var webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
var mock_1 = __importDefault(require("./middleware/mock"));
var logger_1 = __importDefault(require("./middleware/logger"));
var utils_1 = __importDefault(require("./utils"));
var clearConsole_1 = __importDefault(require("./clearConsole"));
var getExtraConfig_1 = __importDefault(require("./getExtraConfig"));
var getWebpackConfig_1 = __importDefault(require("./getWebpackConfig"));
var compilerErrorHandle_1 = __importDefault(require("./compilerErrorHandle"));
var HOST = '127.0.0.1';
var PORT = 3000;
function runServer(options) {
    var extraConfig = getExtraConfig_1.default();
    var devServerConfig = {
        host: extraConfig.rcb.host || HOST,
        port: extraConfig.rcb.port || PORT,
        proxy: extraConfig.rcb.proxy,
        quiet: true,
        overlay: true,
        disableHostCheck: true,
        historyApiFallback: {
            htmlAcceptHeaders: ['text/html', 'application/xhtml+xml', 'application/xml']
        },
        compress: true,
        clientLogLevel: 'none',
        hot: true,
        inline: true,
        watchOptions: {
            ignored: /node_modules/
        },
        open: true,
        setup: function (app) {
            if (options.mock) {
                // mock代理的url不会在node中log出来，只有proxy代理的url才会log方便查看是哪里出了问题
                app.use(mock_1.default.mockConfig.api, mock_1.default.middleware());
            }
            app.use(logger_1.default());
        }
    };
    var webpackConfig = getWebpackConfig_1.default(extraConfig.webpack, { devServer: devServerConfig });
    var URL = "http://" + devServerConfig.host + ":" + devServerConfig.port;
    var compiler = webpack_1.default(webpackConfig);
    var server = new webpack_dev_server_1.default(compiler, devServerConfig);
    var isFirstCompiler = true;
    compiler.hooks.beforeCompile.tap('beforeCompile', function () {
        if (isFirstCompiler) {
            return;
        }
        utils_1.default.success(utils_1.default.chalk.green('Rebuild start...'));
    });
    compiler.hooks.done.tap('dev server', function (stats) {
        if (isFirstCompiler) {
            var proxyPaths = utils_1.default.getWebpackProxyPath(webpackConfig);
            utils_1.default.success(utils_1.default.chalk.green('Local:') + "  " + URL);
            if (proxyPaths.length > 0) {
                utils_1.default.success(utils_1.default.chalk.green('Proxy:') + "  [" + proxyPaths.join(', ') + "]");
            }
            utils_1.default.success(utils_1.default.chalk.green('Compiled successfully!'));
            isFirstCompiler = false;
        }
        else {
            utils_1.default.success(utils_1.default.chalk.green('Compiled successfully!'));
        }
        compilerErrorHandle_1.default(stats, null, isFirstCompiler);
    });
    if (!devServerConfig.port || !devServerConfig.host) {
        utils_1.default.error("port: " + devServerConfig.port + ", host: " + devServerConfig.host);
        process.exit(0);
    }
    server.listen(devServerConfig.port, devServerConfig.host, function () {
        if (isFirstCompiler) {
            clearConsole_1.default();
        }
        utils_1.default.success(utils_1.default.chalk.green('Server starting...'));
    });
}
exports.default = runServer;
;
