/**
 * @file getCssLoader
 * @author WenCe
 */
import webpack from 'webpack';
import MiniCssExtractPlugin from 'mini-css-extract-plugin';
import utils from '../utils';
const cssRegex = /.css$/;

function getStyleLoader(preLoader?: webpack.Loader) {
    const loader: webpack.Loader[] = [
        {
            loader: MiniCssExtractPlugin.loader,
            options: {
                hmr: utils.isDev()
            }
        },
        require.resolve('css-loader'),
        {
            loader: require.resolve('postcss-loader'), options: {
                plugins: [
                    require(require.resolve('postcss-flexbugs-fixes')),
                    require(require.resolve('postcss-preset-env'))({
                        autoprefixer: {
                            flexbox: 'no-2009'
                        },
                        stage: 3
                    })
                ]
            }
        },
        require.resolve('resolve-url-loader')
    ];

    if (preLoader) {
        loader.push(preLoader);
    }

    return loader;
}

function getCssLoader() {
    return ({
        test: cssRegex,
        use: getStyleLoader()
    });
}

getCssLoader.getStyleLoader = getStyleLoader;

export default getCssLoader;
