/**
 * @file getPlugins
 * @author WenCe
 */
import path from 'path';
import webpack, {DefinePlugin} from 'webpack';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import MiniCssExtractPlugin from 'mini-css-extract-plugin';

import utils from './utils';

function addPlugins(basePlugins: webpack.ResolvePlugin[], plugins?: webpack.ResolvePlugin[]) {
    if (plugins) {
        plugins.forEach(function (plugin: HtmlWebpackPlugin | DefinePlugin) {
            basePlugins.push(plugin);
        });
    }

    return basePlugins;
}

export default function getPlugins() {
    const basePlugins: webpack.ResolvePlugin[] = [
        new HtmlWebpackPlugin({
            template: path.resolve(process.cwd(), './public/index.html'),
            multiStep: true
        }),
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify(utils.getEnv())
            }
        })
    ];

    if (utils.isDev()) {
        addPlugins(basePlugins, [
            new webpack.HotModuleReplacementPlugin(),
            new MiniCssExtractPlugin({
                filename: 'css/[name].css'
            })
        ]);
    }

    if (utils.isProduction()) {
        addPlugins(basePlugins, [
            new MiniCssExtractPlugin({
                filename: 'css/[name].[hash:8].css'
            })
        ]);
    }

    return basePlugins;
};
