/**
 * @file webpack.config.base
 * @author WenCe
 */
import webpack from 'webpack';
import webpackDevServer from 'webpack-dev-server';
import {merge} from 'webpack-merge';
import PnpWebpackPlugin from 'pnp-webpack-plugin';

import getOutput from './getOutput';
import getLoaders from './getLoaders';
import getPlugins from './getPlugins';
import getOptimization from './getOptimization';

import utils from './utils';

const entry = ['./src/index'];

interface Configuration extends webpack.Configuration {
    devServer?: webpackDevServer.Configuration
}

export default (...configurations: Configuration[]) => merge({
    mode: utils.getEnv(),
    performance: {
        hints: false
    },
    devtool: utils.isDev() ? 'cheap-module-eval-source-map' : false,
    entry: entry,
    output: getOutput(),
    module: {
        rules: getLoaders()
    },
    optimization: getOptimization(),
    plugins: getPlugins(),
    resolve: {
        plugins: [PnpWebpackPlugin],
        extensions: ['.js', '.jsx', '.es6', '.json', '.ts', '.tsx']
    },
    resolveLoader: {
        plugins: [
            PnpWebpackPlugin.moduleLoader(module)
        ]
    }
}, ...configurations);
